==> flowable-engine-6.2.1-sources.jar: org/flowable/engine/impl/cmd/GetCommentCmd.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.flowable.engine.impl.cmd;

import java.io.Serializable;

import org.flowable.engine.common.api.FlowableIllegalArgumentException;
import org.flowable.engine.common.impl.interceptor.Command;
import org.flowable.engine.common.impl.interceptor.CommandContext;
import org.flowable.engine.impl.util.CommandContextUtil;
import org.flowable.engine.task.Comment;

/**
 * @author Frederik Heremans
 */
public class GetCommentCmd implements Command<Comment>, Serializable {

    private static final long serialVersionUID = 1L;
    protected String commentId;

    public GetCommentCmd(String commentId) {
        this.commentId = commentId;

        if (commentId == null) {
            throw new FlowableIllegalArgumentException("commentId is null");
        }
    }

    @Override
    public Comment execute(CommandContext commandContext) {
        return CommandContextUtil.getCommentEntityManager(commandContext).findComment(commentId);
    }
}

==> flowable-engine-6.8.0-sources.jar: org/flowable/engine/impl/cmd/GetCommentCmd.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.flowable.engine.impl.cmd;

import java.io.Serializable;

import org.flowable.common.engine.api.FlowableIllegalArgumentException;
import org.flowable.common.engine.impl.interceptor.Command;
import org.flowable.common.engine.impl.interceptor.CommandContext;
import org.flowable.engine.impl.util.CommandContextUtil;
import org.flowable.engine.task.Comment;

/**
 * @author Frederik Heremans
 */
public class GetCommentCmd implements Command<Comment>, Serializable {

    private static final long serialVersionUID = 1L;
    protected String commentId;

    public GetCommentCmd(String commentId) {
        this.commentId = commentId;

        if (commentId == null) {
            throw new FlowableIllegalArgumentException("commentId is null");
        }
    }

    @Override
    public Comment execute(CommandContext commandContext) {
        return CommandContextUtil.getCommentEntityManager(commandContext).findComment(commentId);
    }
}
